==> github-widget2-1.0.0.tgz: package/lib/test/org.test.js <==
'use strict';

var _jsxFileName = '../../src/test/org.test.jsx';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Org = require('../components/Org/Org');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        orgs: {
          ids: [238923429],
          orgsById: {
            238923429: {
              avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
              orgName: 'ShareCastG52',
              reposUrl: 'https://api.github.com/orgs/ShareCastG52/repos'
            }
          }
        },
        loadingOrganizations: false
      }
    }
  }
};

describe('Org entry component', function () {
  it('should render a component with props as specified ', function () {
    var displayRepos = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Org.Org, {
      avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
      orgName: 'ShareCastG52',
      displayRepos: displayRepos,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 30
      },
      __self: undefined
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it('map\'s given State To Props ', function () {
    var expected = {
      avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
      orgName: 'ShareCastG52'
    };
    expect((0, _Org.mapStateToProps)(state, { orgId: 238923429, widgetId: 'github' })).toEqual(expected);
  });
});

==> github-widget2-1.0.4.tgz: package/lib/test/org.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Org = require('../components/Org/Org');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        orgs: {
          ids: [238923429],
          orgsById: {
            238923429: {
              avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
              orgName: 'ShareCastG52',
              reposUrl: 'https://api.github.com/orgs/ShareCastG52/repos'
            }
          }
        },
        loadingOrganizations: false
      }
    }
  }
};

describe('Org entry component', function () {
  it('should render a component with props as specified ', function () {
    var displayRepos = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Org.Org, {
      avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
      orgName: 'ShareCastG52',
      displayRepos: displayRepos
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it('map\'s given State To Props ', function () {
    var expected = {
      avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
      orgName: 'ShareCastG52'
    };
    expect((0, _Org.mapStateToProps)(state, { orgId: 238923429, widgetId: 'github' })).toEqual(expected);
  });
});
